"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DescribeDatabaseCommand = void 0;
const middleware_endpoint_discovery_1 = require("@aws-sdk/middleware-endpoint-discovery");
const middleware_serde_1 = require("@aws-sdk/middleware-serde");
const smithy_client_1 = require("@aws-sdk/smithy-client");
const models_0_1 = require("../models/models_0");
const Aws_json1_0_1 = require("../protocols/Aws_json1_0");
class DescribeDatabaseCommand extends smithy_client_1.Command {
    constructor(input) {
        super();
        this.input = input;
    }
    resolveMiddleware(clientStack, configuration, options) {
        this.middlewareStack.use((0, middleware_serde_1.getSerdePlugin)(configuration, this.serialize, this.deserialize));
        this.middlewareStack.use((0, middleware_endpoint_discovery_1.getEndpointDiscoveryPlugin)(configuration, { clientStack, options, isDiscoveredEndpointRequired: true }));
        const stack = clientStack.concat(this.middlewareStack);
        const { logger } = configuration;
        const clientName = "TimestreamWriteClient";
        const commandName = "DescribeDatabaseCommand";
        const handlerExecutionContext = {
            logger,
            clientName,
            commandName,
            inputFilterSensitiveLog: models_0_1.DescribeDatabaseRequest.filterSensitiveLog,
            outputFilterSensitiveLog: models_0_1.DescribeDatabaseResponse.filterSensitiveLog,
        };
        const { requestHandler } = configuration;
        return stack.resolve((request) => requestHandler.handle(request.request, options || {}), handlerExecutionContext);
    }
    serialize(input, context) {
        return (0, Aws_json1_0_1.serializeAws_json1_0DescribeDatabaseCommand)(input, context);
    }
    deserialize(output, context) {
        return (0, Aws_json1_0_1.deserializeAws_json1_0DescribeDatabaseCommand)(output, context);
    }
}
exports.DescribeDatabaseCommand = DescribeDatabaseCommand;
