"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListTables = void 0;
const ListTablesCommand_1 = require("../commands/ListTablesCommand");
const TimestreamWrite_1 = require("../TimestreamWrite");
const TimestreamWriteClient_1 = require("../TimestreamWriteClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListTablesCommand_1.ListTablesCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listTables(input, ...args);
};
async function* paginateListTables(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof TimestreamWrite_1.TimestreamWrite) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof TimestreamWriteClient_1.TimestreamWriteClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected TimestreamWrite | TimestreamWriteClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListTables = paginateListTables;
